from rest_framework.pagination import (
    LimitOffsetPagination,
    remove_query_param,
    replace_query_param
)


class Pagination(LimitOffsetPagination):
    default_limit = 10

    def get_next_link(self):
        if self.offset + self.limit >= self.count:
            return None

        return replace_query_param(
            '?' + self.request.META['QUERY_STRING'],
            self.offset_query_param,
            self.offset + self.limit
        )

    def get_previous_link(self):
        if self.offset <= 0:
            return None

        url = '?' + self.request.META['QUERY_STRING']

        if self.offset - self.limit <= 0:
            return remove_query_param(url, self.offset_query_param)

        return replace_query_param(url, self.offset_query_param, self.offset - self.limit)



# Generated by Django 5.0.2 on 2024-07-19 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budgetmanager', '0003_sharecode'),
    ]

    operations = [
        migrations.AddField(
            model_name='budget',
            name='last_used',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name='payee',
            name='last_used',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
